/*
 * Daneel - Dalvik to Java bytecode compiler
 * Copyright (C) 2011  IcedRobot team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * This file is subject to the "Classpath" exception:
 *
 * Linking this library statically or dynamically with other modules is
 * making a combined work based on this library.  Thus, the terms and
 * conditions of the GNU General Public License cover the whole
 * combination.
 *
 * As a special exception, the copyright holders of this library give you
 * permission to link this library with independent modules to produce an
 * executable, regardless of the license terms of these independent
 * modules, and to copy and distribute the resulting executable under terms
 * of your choice, provided that you also meet, for each linked independent
 * module, the terms and conditions of the license of that module.  An
 * independent module is a module which is not derived from or based on
 * this library.  If you modify this library, you may extend this exception
 * to your version of the library, but you are not obligated to do so.  If
 * you do not wish to do so, delete this exception statement from your
 * version.
 */

package org.icedrobot.daneel.rewriter;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertFalse;

import org.icedrobot.daneel.DexifyingRunner;
import org.junit.Test;
import org.junit.runner.RunWith;

@RunWith(DexifyingRunner.class)
public class InvokeWithoutMoveResultTest {

    @Test
    public void test() {
        DEXCode.invoke();
    }

    @Test
    public void testBoolean() {
        assertFalse(DEXCode.f_boolean());
    }

    @Test
    public void testByte() {
        assertEquals(0, DEXCode.f_byte());
    }

    @Test
    public void testChar() {
        assertEquals(0, DEXCode.f_char());
    }

    @Test
    public void testShort() {
        assertEquals(0, DEXCode.f_short());
    }

    @Test
    public void testInt() {
        assertEquals(0, DEXCode.f_int());
    }

    @Test
    public void testLong() {
        assertEquals(0, DEXCode.f_long());
    }

    @Test
    public void testFloat() {
        assertEquals(0, DEXCode.f_float(), 0);
    }

    @Test
    public void testDouble() {
        assertEquals(0, DEXCode.f_double(), 0);
    }

    // Keep this class named "DEXCode" to push it through Daneel.
    private static class DEXCode {
        static void f_void() { }
        static boolean f_boolean() { return false; }
        static byte f_byte() { return 0; }
        static char f_char() { return 0; }
        static short f_short() { return 0; }
        static int f_int() { return 0; }
        static long f_long() { return 0; }
        static float f_float() { return 0; }
        static double f_double() { return 0; }

        public static void invoke() {
            f_void();
            f_boolean();
            f_byte();
            f_char();
            f_short();
            f_int();
            f_long();
            f_float();
            f_double();
        }
    };
}
